.. include:: ../README.rst

.. toctree::
   :maxdepth: 2
   :hidden:

   installation
   usage
   contributing
   changelog

.. toctree::
   :maxdepth: 2
   :hidden:
   :caption: Reference

   reference/client
   reference/events
   reference/exceptions
   reference/leases
   reference/locks
   reference/members
   reference/utils
